using System;
using System.Runtime.InteropServices;

/// <summary>
/// FAD-16H API library definitions
/// </summary>
public class FAD16H
{
    //
    // Device status (Return codes)
    //
    public const int FAD16H_OK = 0;
    public const int FAD16H_INVALID_ID = 1;
    public const int FAD16H_DEVICE_NOT_FOUND = 2;
    public const int FAD16H_DEVICE_NOT_OPENED = 3;
    public const int FAD16H_OTHER_ERROR = 4;
    public const int FAD16H_COMMUNICATION_ERROR = 5;
    public const int FAD16H_INVALID_PARAMETER = 6;
    public const int FAD16H_MEMORY_ERROR = 7;

    //
    // Device Type
    //
    public const byte FAD16H_DEVICE_TYPE_S = 0x00;	// FAD-16HS
    public const byte FAD16H_DEVICE_TYPE_T = 0x01;	// FAD-16HT

    //
    // Sampling Rate
    //
    public const int FAD16H_SAMPLING_RATE_2MSPS = 10;
    public const int FAD16H_SAMPLING_RATE_1MSPS = 20;
    public const int FAD16H_SAMPLING_RATE_500KSPS = 40;
    public const int FAD16H_SAMPLING_RATE_200KSPS = 100;
    public const int FAD16H_SAMPLING_RATE_100KSPS = 200;
    public const int FAD16H_SAMPLING_RATE_50KSPS = 400;
    public const int FAD16H_SAMPLING_RATE_20KSPS = 1000;
    public const int FAD16H_SAMPLING_RATE_10KSPS = 2000;
    public const int FAD16H_SAMPLING_RATE_5KSPS = 4000;
    public const int FAD16H_SAMPLING_RATE_2KSPS = 10000;
    public const int FAD16H_SAMPLING_RATE_1KSPS = 20000;
    public const int FAD16H_SAMPLING_RATE_500SPS = 40000;
    public const int FAD16H_SAMPLING_RATE_200SPS = 100000;
    public const int FAD16H_SAMPLING_RATE_100SPS = 200000;
    public const int FAD16H_SAMPLING_RATE_50SPS = 400000;
    public const int FAD16H_SAMPLING_RATE_20SPS = 1000000;
    public const int FAD16H_SAMPLING_RATE_10SPS = 2000000;

    //
    // Sampling Mode
    //
    public const byte FAD16H_SAMPLING_MODE_INTERNAL = 0x00;				// Internal clock
    public const byte FAD16H_SAMPLING_MODE_EXTERNAL_EDGE_ON = 0x01;		// External clock edge on
    public const byte FAD16H_SAMPLING_MODE_EXTERNAL_EDGE_OFF = 0x02;	// External clock edge off

    //
    // Trigger Type
    //
    public const byte FAD16H_TRIGGER_TYPE_LEVEL_H = 0x00;
    public const byte FAD16H_TRIGGER_TYPE_LEVEL_L = 0x01;
    public const byte FAD16H_TRIGGER_TYPE_SLOPE_RISING = 0x02;
    public const byte FAD16H_TRIGGER_TYPE_SLOPE_FALLING = 0x03;
    public const byte FAD16H_TRIGGER_TYPE_EDGE_ON = 0x04;
    public const byte FAD16H_TRIGGER_TYPE_EDGE_OFF = 0x05;

    //
    // Device Functions
    //
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_GetNumberOfDevices (out int Number);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_GetSerialNumber (int Index, out int SerialNumber);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_Open (out byte ID);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_OpenBySerialNumber (int SerialNumber, out byte ID);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_Close(byte ID);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_GetDeviceType(byte ID, out byte DeviceType);

    //
    // A/D Functions
    //
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_Start (byte ID, byte SamplingMode, int SamplingRate, int SamplingCount);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_TriggerStart (byte ID, byte SamplingMode, int SamplingRate, int PostTriggerCount, byte TriggerType, double TriggerThreshold, int TriggerOccurs);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_Stop(byte ID);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_GetStatus(byte ID, out byte MemoryStatus, out byte TriggerStatus, out byte ExtTriggerState, out byte ExtClockState);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_GetMemoryWriteCount(byte ID, out int Count);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_GetTriggerAddr(byte ID, out int Addr);
    [DllImport("FAD16H.dll")]
    public static extern int FAD16H_ReadMemory (byte ID, [MarshalAs(UnmanagedType.AsAny), InAttribute(), OutAttribute()] object Data, int Addr, int Count);
}
