/*++

Copyright (c) 2017 ELMOS Co., Ltd.

Module Name:
	FAD16H.h
Abstract:
	FAD16H API library definitions
Revision History:
	17/07/13	Created.

--*/

#ifndef FAD16H_H
#define FAD16H_H

#ifdef FAD16H_EXPORTS_
#define FAD16H_API __declspec(dllexport)
#else
#define FAD16H_API __declspec(dllimport)
#endif

//
// Device status (Return Value)
//
enum {
    FAD16H_OK,
    FAD16H_INVALID_ID,
    FAD16H_DEVICE_NOT_FOUND,
    FAD16H_DEVICE_NOT_OPENED,
	FAD16H_OTHER_ERROR,
	FAD16H_COMMUNICATION_ERROR,
	FAD16H_INVALID_PARAMETER,
	FAD16H_MEMORY_ERROR
};

//
// Constants
//

// Device Type
#define	FAD16H_DEVICE_TYPE_S	0x00	// FAD-16HS
#define	FAD16H_DEVICE_TYPE_T	0x01	// FAD-16HT

// Sampling Rate
#define	FAD16H_SAMPLING_RATE_2MSPS		10
#define	FAD16H_SAMPLING_RATE_1MSPS		20
#define	FAD16H_SAMPLING_RATE_500KSPS	40
#define	FAD16H_SAMPLING_RATE_200KSPS	100
#define	FAD16H_SAMPLING_RATE_100KSPS	200
#define	FAD16H_SAMPLING_RATE_50KSPS		400
#define	FAD16H_SAMPLING_RATE_20KSPS		1000
#define	FAD16H_SAMPLING_RATE_10KSPS		2000
#define	FAD16H_SAMPLING_RATE_5KSPS		4000
#define	FAD16H_SAMPLING_RATE_2KSPS		10000
#define	FAD16H_SAMPLING_RATE_1KSPS		20000
#define	FAD16H_SAMPLING_RATE_500SPS		40000
#define	FAD16H_SAMPLING_RATE_200SPS		100000
#define	FAD16H_SAMPLING_RATE_100SPS		200000
#define	FAD16H_SAMPLING_RATE_50SPS		400000
#define	FAD16H_SAMPLING_RATE_20SPS		1000000
#define	FAD16H_SAMPLING_RATE_10SPS		2000000

// Sampling Mode
#define	FAD16H_SAMPLING_MODE_INTERNAL			0x00	// Internal clock
#define	FAD16H_SAMPLING_MODE_EXTERNAL_EDGE_ON	0x01	// External clock edge on
#define	FAD16H_SAMPLING_MODE_EXTERNAL_EDGE_OFF	0x02	// External clock edge off

// Trigger Type
#define	FAD16H_TRIGGER_TYPE_LEVEL_H			0x00
#define	FAD16H_TRIGGER_TYPE_LEVEL_L			0x01
#define	FAD16H_TRIGGER_TYPE_SLOPE_RISING	0x02
#define	FAD16H_TRIGGER_TYPE_SLOPE_FALLING	0x03
#define	FAD16H_TRIGGER_TYPE_EDGE_ON			0x04
#define	FAD16H_TRIGGER_TYPE_EDGE_OFF		0x05


#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
FAD16H_API int WINAPI FAD16H_GetNumberOfDevices (int *Number);
FAD16H_API int WINAPI FAD16H_GetSerialNumber (int Index, int *SerialNumber);
FAD16H_API int WINAPI FAD16H_Open (BYTE *ID);
FAD16H_API int WINAPI FAD16H_OpenBySerialNumber (int SerialNumber, BYTE *ID);
FAD16H_API int WINAPI FAD16H_Close (BYTE ID);
FAD16H_API int WINAPI FAD16H_GetDeviceType (BYTE ID, BYTE *DeviceType);

FAD16H_API int WINAPI FAD16H_Start (BYTE ID, BYTE SamplingMode, int SamplingRate, int SamplingCount);
FAD16H_API int WINAPI FAD16H_TriggerStart (BYTE ID, BYTE SamplingMode, int SamplingRate, int PostTriggerCount, BYTE TriggerType, double TriggerThreshold, int TriggerOccurs);
FAD16H_API int WINAPI FAD16H_Stop (BYTE ID);
FAD16H_API int WINAPI FAD16H_GetStatus (BYTE ID, BYTE *MemoryStatus, BYTE *TriggerStatus, BYTE *ExtTriggerState, BYTE *ExtClockState);
FAD16H_API int WINAPI FAD16H_GetMemoryWriteCount (BYTE ID, int *Count);
FAD16H_API int WINAPI FAD16H_GetTriggerAddr (BYTE ID, int *Addr);
FAD16H_API int WINAPI FAD16H_ReadMemory (BYTE ID, double *Data, int Addr, int Count);

#ifdef __cplusplus
}
#endif

#endif  /* FAD16H_H */
